==> apache-hop-2.15.0-src.tar.gz: apache-hop-2.15.0/plugins/transforms/standardizephonenumber/src/test/java/org/apache/hop/pipeline/transforms/standardizephonenumber/StandardizePhoneNumberMetaInjectionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.standardizephonenumber;

import org.apache.hop.core.injection.BaseMetadataInjectionTest;
import org.apache.hop.junit.rules.RestoreHopEngineEnvironment;
import org.junit.Before;
import org.junit.ClassRule;
import org.junit.Test;

public class StandardizePhoneNumberMetaInjectionTest
    extends BaseMetadataInjectionTest<StandardizePhoneNumberMeta> {
  @ClassRule public static RestoreHopEngineEnvironment env = new RestoreHopEngineEnvironment();

  @Before
  public void setup() throws Exception {
    setup(new StandardizePhoneNumberMeta());
  }

  @Test
  public void test() throws Exception {
    check("input", () -> meta.getFields().get(0).getInputField());
    check("output", () -> meta.getFields().get(0).getOutputField());
    check("format", () -> meta.getFields().get(0).getNumberFormat());
    check("country", () -> meta.getFields().get(0).getCountryField());
    check("defaultCountry", () -> meta.getFields().get(0).getDefaultCountry());
    check("numbertype", () -> meta.getFields().get(0).getNumberTypeField());
    check("isvalidnumber", () -> meta.getFields().get(0).getIsValidNumberField());
  }
}

==> apache-hop-2.16.0-src.tar.gz: apache-hop-2.16.0/plugins/transforms/standardizephonenumber/src/test/java/org/apache/hop/pipeline/transforms/standardizephonenumber/StandardizePhoneNumberMetaInjectionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.standardizephonenumber;

import org.apache.hop.core.injection.BaseMetadataInjectionTestJunit5;
import org.apache.hop.junit.rules.RestoreHopEngineEnvironmentExtension;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.RegisterExtension;

class StandardizePhoneNumberMetaInjectionTest
    extends BaseMetadataInjectionTestJunit5<StandardizePhoneNumberMeta> {
  @RegisterExtension
  static RestoreHopEngineEnvironmentExtension env = new RestoreHopEngineEnvironmentExtension();

  @BeforeEach
  void setup() throws Exception {
    setup(new StandardizePhoneNumberMeta());
  }

  @Test
  void test() throws Exception {
    check("input", () -> meta.getFields().get(0).getInputField());
    check("output", () -> meta.getFields().get(0).getOutputField());
    check("format", () -> meta.getFields().get(0).getNumberFormat());
    check("country", () -> meta.getFields().get(0).getCountryField());
    check("defaultCountry", () -> meta.getFields().get(0).getDefaultCountry());
    check("numbertype", () -> meta.getFields().get(0).getNumberTypeField());
    check("isvalidnumber", () -> meta.getFields().get(0).getIsValidNumberField());
  }
}
